@@ -4,6 +4,6 @@ import equihash
 
 n=102
 k=5
-seed="some initial seed"
+seed=b"some initial seed"
 sol = equihash.solve(n, k, seed)
 print(equihash.verify(n,k,seed,sol))
